DateTimeAnchor

Enum DateTimeAnchor 

#[non_exhaustive]
pub enum DateTimeAnchor { InDays(i64), Relative(i64), DateTime(LooseDateTime), Time(Time), MonthDay(i8, i8), Weekday { day: Weekday, offset: i8, }, }
Represents a date and time anchor that can be used to calculate relative dates and times.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InDays(i64)

A specific number of days in the future or past.



Relative(i64)

A specific number of seconds in the future or past.



DateTime(LooseDateTime)

A specific date and time.



Time(Time)

A specific time.



MonthDay(i8, i8)

A month and day without year (year resolved at resolution time).



Weekday

A weekday with optional offset in weeks.

Fields

day: Weekday

The target weekday.

offset: i8

Offset for weekday resolution in weeks.

  • 0 = This/next occurrence (could be today if same weekday)
  • 1 = Next week’s occurrence
  • 2 = 2 weeks from now
  • -1 = Last/previous occurrence
  • -2 = 2 weeks ago

Implementations

Source

impl DateTimeAnchor

pub fn now() -> Self

Represents the current time.

pub fn today() -> Self

Represents the current date.

pub fn tomorrow() -> Self

Represents tomorrow, which is one day after today.

pub fn yesterday() -> Self

Represents yesterday, which is one day before today.

pub fn resolve_at_start_of_day(&self, now: &Zoned) -> Result<Zoned, String>

Resolve datetime at the start of the day based on the provided current local time.

Errors

Returns an error if date/time operations fail.

pub fn resolve_at_end_of_day(&self, now: &Zoned) -> Result<Zoned, String>

Resolve datetime at the end of the day based on the provided current local time.

Errors

Returns an error if date/time operations fail.

pub fn resolve_at(self, now: &LooseDateTime) -> LooseDateTime

Resolve the DateTimeAnchor to a LooseDateTime based on the provided current local time.

pub fn resolve_since( self, start: &LooseDateTime, ) -> Result<LooseDateTime, String>

Resolve the DateTimeAnchor to a LooseDateTime starting from the provided LooseDateTime.

Errors

Returns an error if date/time operations fail.

pub fn resolve_since_zoned(self, start: &Zoned) -> Result<LooseDateTime, String>

Resolve the DateTimeAnchor to a LooseDateTime starting from the provided Zoned.

Errors

Returns an error if date/time operations fail.