pub struct TodoConditions {
pub status: Option<TodoStatus>,
pub due: Option<DateTimeAnchor>,
pub calendar_id: Option<String>,
}Expand description
Conditions for filtering todo items, such as current time, status, and due date.
Fields
status: Option<TodoStatus>The status of the todo item to filter by, if any.
due: Option<DateTimeAnchor>The priority of the todo item to filter by, if any.
calendar_id: Option<String>The calendar ID to filter todos by