Core library for the AIM calendar application.
Structs
- Aim
- AIM calendar application core.
- Caldav
Store CalDAVstore implementation.- Calendar
Details - Detailed information for a single calendar.
- Calendar
Entry - Calendar entry in the TOML configuration.
- Calendar
Record - Calendar record stored in database.
- Config
- Configuration for the AIM application.
- Event
Conditions - Conditions for filtering events in a calendar.
- Event
Draft - Darft for an event, used for creating new events.
- Event
Patch - Patch for an event, allowing partial updates.
- Local
Store - Local file-based store for storing events and todos as ICS files.
- Pager
- Pagination with a limit and an offset.
- Sync
Result - Result of a backend synchronization operation.
- Todo
Conditions - Conditions for filtering todo items, such as current time, status, and due date.
- Todo
Draft - Darft for a todo item, used for creating new todos.
- Todo
Patch - Patch for a todo item, allowing partial updates.
Enums
- Auth
Method CalDAVauthentication method.- Calendar
Store Details - Store-specific details for a calendar.
- Date
Time Anchor - Represents a date and time anchor that can be used to calculate relative dates and times.
- Event
Status - The status of an event, which can be tentative, confirmed, or cancelled.
- Id
- The unique identifier for a todo item, which can be either a UID or a short ID.
- Kind
- Kind of item, either an event or a todo.
- Loose
Date Time - A date and time that may be in different formats, such as date only, floating time, or local time with timezone.
- Priority
- Priority of a task or item, with values ranging from 1 to 9, and None for no priority.
- Range
Position - The position of a date relative to a range defined by a start and optional end date.
- Sort
Order - Sort order, either ascending or descending.
- Store
Def - Store definition for shared connection configuration.
- Store
Kind - Store type for events and todos
- Todo
Sort - The default sort key for todo items, which is by due date.
- Todo
Status - The status of a todo item, which can be one of several predefined states.
Constants
- APP_
NAME - The name of the AIM application.
Traits
- Event
- Trait representing a calendar event.
- Store
- Store trait for storing and synchronizing events and todos.
- Todo
- Trait representing a todo item.
Type Aliases
- Store
Error - Error type for store operations that is Send + Sync.