pub struct Aim { /* private fields */ }Expand description
AIM calendar application core.
Implementations
Sourceimpl Aim
impl Aim
Sourcepub fn refresh_now(&mut self)
pub fn refresh_now(&mut self)
Refresh the current time to now.
Sourcepub fn default_event_draft(&self) -> EventDraft
pub fn default_event_draft(&self) -> EventDraft
Create a default event draft based on the AIM configuration.
Sourcepub async fn find_latest_event_by_summary(
&self,
summary: &str,
) -> Result<Option<impl Event + 'static>, Box<dyn Error>>
pub async fn find_latest_event_by_summary( &self, summary: &str, ) -> Result<Option<impl Event + 'static>, Box<dyn Error>>
Sourcepub async fn new_event(
&self,
draft: EventDraft,
) -> Result<impl Event + 'static, Box<dyn Error>>
pub async fn new_event( &self, draft: EventDraft, ) -> Result<impl Event + 'static, Box<dyn Error>>
Add a new event from the given draft.
Errors
If the event is not found, database or backend access fails.
Sourcepub async fn update_event(
&self,
id: &Id,
patch: EventPatch,
) -> Result<impl Event + 'static, Box<dyn Error>>
pub async fn update_event( &self, id: &Id, patch: EventPatch, ) -> Result<impl Event + 'static, Box<dyn Error>>
Upsert an event into the calendar.
Errors
If the event is not found, database or backend access fails.
Sourcepub async fn get_kind(&self, id: &Id) -> Result<Kind, Box<dyn Error>>
pub async fn get_kind(&self, id: &Id) -> Result<Kind, Box<dyn Error>>
Get the kind of the given id, which can be either an event or a todo.
Errors
If the id is not found or database access fails.
Sourcepub async fn list_events(
&self,
conds: &EventConditions,
pager: &Pager,
) -> Result<Vec<impl Event + 'static>, Box<dyn Error>>
pub async fn list_events( &self, conds: &EventConditions, pager: &Pager, ) -> Result<Vec<impl Event + 'static>, Box<dyn Error>>
Sourcepub async fn count_events(
&self,
conds: &EventConditions,
) -> Result<i64, Box<dyn Error>>
pub async fn count_events( &self, conds: &EventConditions, ) -> Result<i64, Box<dyn Error>>
Sourcepub fn default_todo_draft(&self) -> Result<TodoDraft, String>
pub fn default_todo_draft(&self) -> Result<TodoDraft, String>
Sourcepub async fn find_latest_todo_by_summary(
&self,
summary: &str,
) -> Result<Option<impl Todo + 'static>, Box<dyn Error>>
pub async fn find_latest_todo_by_summary( &self, summary: &str, ) -> Result<Option<impl Todo + 'static>, Box<dyn Error>>
Sourcepub async fn new_todo(
&self,
draft: TodoDraft,
) -> Result<impl Todo + 'static, Box<dyn Error>>
pub async fn new_todo( &self, draft: TodoDraft, ) -> Result<impl Todo + 'static, Box<dyn Error>>
Add a new todo from the given draft.
Errors
If the todo is not found, database or backend access fails.
Sourcepub async fn update_todo(
&self,
id: &Id,
patch: TodoPatch,
) -> Result<impl Todo + 'static, Box<dyn Error>>
pub async fn update_todo( &self, id: &Id, patch: TodoPatch, ) -> Result<impl Todo + 'static, Box<dyn Error>>
Upsert a todo into the calendar.
Errors
If the todo is not found, database or backend access fails.
Sourcepub async fn list_todos(
&self,
conds: &TodoConditions,
sort: &[TodoSort],
pager: &Pager,
) -> Result<Vec<impl Todo + 'static>, Box<dyn Error>>
pub async fn list_todos( &self, conds: &TodoConditions, sort: &[TodoSort], pager: &Pager, ) -> Result<Vec<impl Todo + 'static>, Box<dyn Error>>
Sourcepub async fn count_todos(
&self,
conds: &TodoConditions,
) -> Result<i64, Box<dyn Error>>
pub async fn count_todos( &self, conds: &TodoConditions, ) -> Result<i64, Box<dyn Error>>
Sourcepub async fn list_calendars(
&self,
) -> Result<Vec<CalendarRecord>, Box<dyn Error>>
pub async fn list_calendars( &self, ) -> Result<Vec<CalendarRecord>, Box<dyn Error>>
Sourcepub async fn get_calendar_details(
&self,
id: &str,
) -> Result<CalendarDetails, Box<dyn Error>>
pub async fn get_calendar_details( &self, id: &str, ) -> Result<CalendarDetails, Box<dyn Error>>
Get detailed information for a single calendar.
Errors
If the calendar is not found or database access fails.
Sourcepub fn startup_notices(&self) -> &[String]
pub fn startup_notices(&self) -> &[String]
Startup notices produced while reconciling config and database state.