pub trait Event {
// Required methods
fn uid(&self) -> Cow<'_, str>;
fn description(&self) -> Option<Cow<'_, str>>;
fn start(&self) -> Option<LooseDateTime>;
fn end(&self) -> Option<LooseDateTime>;
fn status(&self) -> Option<EventStatus>;
fn summary(&self) -> Cow<'_, str>;
// Provided method
fn short_id(&self) -> Option<NonZeroU32> { ... }
}Expand description
Trait representing a calendar event.
Required Methods
Sourcefn description(&self) -> Option<Cow<'_, str>>
fn description(&self) -> Option<Cow<'_, str>>
The description of the event, if available.
Sourcefn start(&self) -> Option<LooseDateTime>
fn start(&self) -> Option<LooseDateTime>
The location of the event, if available.
Sourcefn end(&self) -> Option<LooseDateTime>
fn end(&self) -> Option<LooseDateTime>
The start date and time of the event, if available.
Sourcefn status(&self) -> Option<EventStatus>
fn status(&self) -> Option<EventStatus>
The status of the event, if available.
Provided Methods
Sourcefn short_id(&self) -> Option<NonZeroU32>
fn short_id(&self) -> Option<NonZeroU32>
The short identifier for the event.
It will be None if the event does not have a short ID.
It is used for display purposes and may not be unique.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".